/*****************************************************************************
*   $Id: entry.h,v 1.1 1998/10/18 15:34:57 darren Exp $
*
*   Copyright (c) 1998, Darren Hiebert
*
*   This source code is released for free distribution under the terms of the
*   GNU General Public License.
*
*   External interface to entry.c
*****************************************************************************/
#ifndef _ENTRY_H
#define _ENTRY_H

/*============================================================================
=   Include files
============================================================================*/
#include "general.h"

#include <stdio.h>

#include "ctags.h"
#include "vstring.h"

/*============================================================================
=   Data declarations
============================================================================*/

/*  Maintains the state of the tag file.
 */
typedef struct _tagFile {
    const char *name;
    FILE *fp;
    struct _numTags { unsigned long added, prev; } numTags;
    struct _max { size_t line, tag, file; } max;
    struct _etags {
	char name[L_tmpnam];
	FILE *fp;
	size_t byteCount;
    } etags;
    vString *vLine;
} tagFile;

/*  Describes the type of tag being generated.
 */
typedef enum _tagType {
    TAG_CLASS,			/* class name */
    TAG_DEFINE_OBJ,		/* pre-processor define (object-like) */
    TAG_DEFINE_FUNC,		/* pre-processor define (function-like) */
    TAG_ENUM,			/* enumeration name */
    TAG_ENUMERATOR,		/* enumerator (enumeration value) */
    TAG_FEATURE,		/* feature definition (Eiffel) */
    TAG_FUNCDECL,		/* function declaration */
    TAG_FUNCTION,		/* function (or method) definition */
    TAG_INTERFACE,		/* interface declaration */
    TAG_LOCAL,			/* variable local to routine */
    TAG_MEMBER,			/* structure, class or interface member */
    TAG_NAMESPACE,		/* namespace name */
    TAG_SOURCE_FILE,		/* source file */
    TAG_STRUCT,			/* structure name */
    TAG_TYPEDEF,		/* typedef name */
    TAG_UNION,			/* union name */
    TAG_VARIABLE,		/* variable definition */
    TAG_EXTERN_VAR,		/* external variable declaration */
    TAG_NUMTYPES		/* must be last */
} tagType;

/*  This describes the scoping of the current statement.
 */
typedef enum _tagScope {
    SCOPE_GLOBAL,		/* no storage class specified */
    SCOPE_STATIC,		/* static storage class */
    SCOPE_EXTERN,		/* external storage class */
    SCOPE_FRIEND,		/* declares visibility only */
    SCOPE_TYPEDEF		/* scoping depends upon context */
} tagScope;

/*  Information about the current tag candidate.
 */
typedef struct _tagInfo {
    long    location;		/* file position of line containing name */
    unsigned long lineNumber;	/* line number of tag */
    char    name[MaxNameLength];/* the name of the token */
} tagInfo;

typedef enum _memberType {
    MEMBER_NONE,
    MEMBER_ENUM, MEMBER_CLASS, MEMBER_INTERFACE, MEMBER_NAMESPACE,
    MEMBER_STRUCT, MEMBER_UNION
} memberType;

typedef enum _visibilityType {
    VIS_UNDEFINED, VIS_PUBLIC, VIS_PROTECTED, VIS_PRIVATE
} visibilityType;

/*  Information about the parent class of a member (if any).
 */
typedef struct _memberInfo {
    memberType type;
    visibilityType visibility;	/* current visibility section, if known */
    boolean persistent;		/* persistent across multiple statements? */
    char parent[MaxNameLength];	/* name of the parent data type */
} memberInfo;

/*============================================================================
=   Global variables
============================================================================*/
extern const memberInfo NoClass;
extern tagFile TagFile;

/*============================================================================
=   Function prototypes
============================================================================*/
extern const char *tagTypeName __ARGS((const tagType type));
extern const char *getTypeString __ARGS((const memberType mType));
extern const char *getVisibilityString __ARGS((const visibilityType visibility));
extern void makeTagEntry __ARGS((const tagInfo *const tag, const memberInfo *const pMember, const tagScope scope, const tagType type, const boolean useLineNumber));
extern void makeTag __ARGS((const tagInfo *const tag, const memberInfo *const pMember, const tagScope scope, const tagType type));
extern void makeDefineTag __ARGS((const tagInfo *const tag, const tagScope scope, const boolean parameterized));
extern void addPseudoTags __ARGS((void));
extern long unsigned int updatePseudoTags __ARGS((void));

#endif	/* _ENTRY_H */

/* vi:set tabstop=8 shiftwidth=4: */
