/*****************************************************************************
*   $Id: options.h,v 1.1 1998/10/18 15:34:57 darren Exp $
*
*   Copyright (c) 1998, Darren Hiebert
*
*   This source code is released for free distribution under the terms of the
*   GNU General Public License.
*
*   This module is a global include file.
*****************************************************************************/
#ifndef _OPTIONS_H
#define _OPTIONS_H

#ifdef OPTION_WRITE
# define CONST_OPTION
#else
# define CONST_OPTION const
#endif

/*============================================================================
=   Include files
============================================================================*/
#include "general.h"
#include "ctags.h"	/* to define LANG_COUNT */

/*============================================================================
=   Data declarations
============================================================================*/

/*  This stores the command line options.
 */
typedef struct _optionValues {
    struct _include {		/* include tags for: */
	boolean	classNames;	/* -ic  class names */
	boolean	defines;	/* -id  defines */
	boolean	enumerators;	/* -ie  enumeration value */
	boolean	functions;	/* -if  functions */
	boolean	enumNames;	/* -ig  enum names */
	boolean	interfaceNames;	/* -ii  interface names */
	boolean	locals;		/* -il  local variables */
	boolean	members;	/* -im  data members */
	boolean	namespaceNames;	/* -in  namespace names */
	boolean	prototypes;	/* -ip  function prototypes */
	boolean	structNames;	/* -is  struct names */
	boolean	typedefs;	/* -it  typedefs */
	boolean	unionNames;	/* -iu  unions */
	boolean	variables;	/* -iv  variables */
	boolean	externVars;	/* -ix  extern variables */

	boolean classPrefix;	/* -iC  include tag entries of class::member */
	boolean sourceFiles;	/* -iF  include tags for source files */
	boolean	statics;	/* -iS  include static tags */
    } include;
    struct _ignore {
	char **list;
	unsigned int count, max;
    } ignore;		    /* -I  name of file containing tokens to ignore */
    boolean append;	    /* -a  append to "tags" files */
    boolean backward;	    /* -B  regexp patterns search backwards */
    boolean etags;	    /* -e  output Emacs style tags file */
    enum _locate {
	EX_MIX,		    /* line numbers for defines, patterns otherwise */
	EX_LINENUM,	    /* -n  only line numbers in tag file */
	EX_PATTERN	    /* -N  only patterns in tag file */
    } locate;		    /* --excmd  EX command used to locate tag */
    const char *path;	    /* -p  default path for source files */
    boolean recurse;	    /* -R  recurse into directories */
    boolean sorted;	    /* -u,--sort  sort tags */
    boolean xref;	    /* -x  generate xref output instead */
    const char *fileList;   /* -L  name of file containing names of files */
    const char *tagFileName;/* -o  name of tags file */
    const char *const *headerExt; /* -h  header extensions */
    unsigned int tagFileFormat; /* --format  tag file format (level) */
    boolean if0;	    /* --if0  examine code within "#if 0" branch */
    langType language;	    /* --lang specified language override */
    const char *const *langMap[(int)LANG_COUNT];
			    /* --langmap  language-extension map */
    boolean printTotals;    /* --totals  print cumulative statistics */
    boolean lineDirectives; /* --linedirectives  process #line directives */
#ifdef DEBUG
    int debugLevel;	    /* -D  debugging output */
    unsigned long breakLine;/* -b  source line at which to call lineBreak() */
#endif
} optionValues;

/*============================================================================
=   Global variables
============================================================================*/
extern CONST_OPTION optionValues	Option;

/*============================================================================
=   Function prototypes
============================================================================*/
extern void setDefaultTagFileName __ARGS((void));
extern void setOptionDefaults __ARGS((void));
extern void testEtagsInvocation __ARGS((void));
extern boolean isFileHeader __ARGS((const char *const fileName));
extern langType getFileLanguage __ARGS((const char *const fileName));
extern boolean isIgnoreToken __ARGS((const char *const name, boolean *const pIgnoreParens));
extern void freeIgnoreList __ARGS((void));
extern const char *getLanguageName __ARGS((const langType language));
extern boolean strequiv __ARGS((const char *const s1, const char *const s2));
extern char *const *parseOptions __ARGS((char *const *const argList));
extern void *parseEnvironmentOptions __ARGS((void));

#endif	/* _OPTIONS_H */

/* vi:set tabstop=8 shiftwidth=4: */
